# -*- python -*-
# This file is part of pybliographer
# 
# Copyright (C) 1998-2004 Frederic GOBRY
# Email : gobry@pybliographer.org
# 	   
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2 
# of the License, or (at your option) any later version.
#   
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details. 
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# 
# 

import sys

from Pyblio.GnomeUI.Pybliographic import Pybliographic
from Pyblio.Fields import URL

from Pyblio.GnomeUI import ui_version

print ui_version

main = Pybliographic ()

if len (sys.argv) > 2:
    for file in sys.argv [2:]:
        url = URL (file)
        
        main.open_document (str (url))
else:
    main.new_document ()

import gtk

gtk.main ()

